aboutsummaryrefslogtreecommitdiff
path: root/jenkins/dispatch.groovy
diff options
context:
space:
mode:
Diffstat (limited to 'jenkins/dispatch.groovy')
-rw-r--r--jenkins/dispatch.groovy12
1 files changed, 7 insertions, 5 deletions
diff --git a/jenkins/dispatch.groovy b/jenkins/dispatch.groovy
index ed3639f..5c8f0a6 100644
--- a/jenkins/dispatch.groovy
+++ b/jenkins/dispatch.groovy
@@ -8,7 +8,8 @@
// and manifest files
// BUILD_CONTROL_BRANCH - Branch to obtain from build control repo
// BUILD_CONTROL_TAG - Tag to obtain from build control repo
// CONDA_VERSION - First, then the version is forced to this value.
// CONDA_BUILD_VERSION - Conda-build is installed forced to this version.
// CONDA_BASE_URL - Where to get the conda installer
// UTILS_REPO - Repository holding support utilities
@@ -20,10 +21,10 @@ this.recipes_dir = "conda-recipes"
this.build_status_file = "propagated_build_status"
// The conda installer script to use for various <OS><py_version> combinations.
-this.conda_installers = ["Linux-py2":"Miniconda2-${CONDA_VERSION}-Linux-x86_64.sh",
- "Linux-py3":"Miniconda3-${CONDA_VERSION}-Linux-x86_64.sh",
- "MacOSX-py2":"Miniconda2-${CONDA_VERSION}-MacOSX-x86_64.sh",
- "MacOSX-py3":"Miniconda3-${CONDA_VERSION}-MacOSX-x86_64.sh"]
+this.conda_installers = ["Linux-py2":"Miniconda2-${CONDA_INSTALLER_VERSION}-Linux-x86_64.sh",
+ "Linux-py3":"Miniconda3-${CONDA_INSTALLER_VERSION}-Linux-x86_64.sh",
+ "MacOSX-py2":"Miniconda2-${CONDA_INSTALLER_VERSION}-MacOSX-x86_64.sh",
+ "MacOSX-py3":"Miniconda3-${CONDA_INSTALLER_VERSION}-MacOSX-x86_64.sh"]
// Values controlling the conda index stage which happens after any packages are created.
this.max_publication_tries = 5
@@ -126,6 +127,7 @@ node(LABEL) {
"PY_VERSION: ${PY_VERSION}\n" +
"NUMPY_VERSION: ${NUMPY_VERSION}\n" +
"MANIFEST_FILE: ${MANIFEST_FILE}\n" +
+ "CONDA_INSTALLER_VERSION: ${CONDA_INSTALLER_VERSION}\n" +
"CONDA_VERSION: ${CONDA_VERSION}\n" +
"CONDA_BUILD_VERSION: ${CONDA_BUILD_VERSION}\n" +
"CONDA_BASE_URL: ${CONDA_BASE_URL}\n" +
@@ -8,7 +8,8 @@
// BUILD_CONTROL_BRANCH - Branch to obtain from build control repo
// BUILD_CONTROL_TAG - Tag to obtain from build control repo
-// CONDA_VERSION - First, then the version is forced to this value.
+// CONDA_INSTALLER_VERSION - Conda installer version to use
+// CONDA_VERSION - conda version is forced to this value
// CONDA_BUILD_VERSION - Conda-build is installed forced to this version.
// CONDA_BASE_URL - Where to get the conda installer